@@ -16,25 +16,6 @@
 #' Returns an object.
 #'
 #' @keywords internal
-getOptionOrEnvVar <- function(name, default = NULL, envvar = NULL) {
-  ## Is there an R options set?
-  value <- getOption2(name, default = NULL)
-  if (!is.null(value)) return(value)
-
-  ## Is there an environment variable set?
-  name2 <- sprintf("R_%s", gsub(".", "_", toupper(name), fixed = TRUE))
-  value <- getEnvVar2(name2, default = "")
-  if (nzchar(value)) {
-    ## Coerce environment variable string to the type according to 'default'?
-    if (!is.null(default)) storage.mode(value) <- storage.mode(default)
-    return(value)
-  }
-  
-  ## Nothing was set
-  default
-}
-
-
 getOption2 <- local({
   re <- sprintf("^(future|%s)[.]", .packageName)
   prefixes <- paste(c(.packageName, "future"), ".", sep = "")
@@ -81,13 +62,15 @@ getEnvVar2 <- local({
 })
 
 
-## When 'default' is specified, this is 30x faster than
-## base::getOption().  The difference is that here we use
-## use names(.Options) whereas in 'base' names(options())
-## is used.
-getOption <- local({
-  go <- base::getOption
-  function(x, default = NULL) {
-    if (missing(default) || match(x, table = names(.Options), nomatch = 0L) > 0L) go(x) else default
-  }
-})
+if (getRversion() < "4.0.0") {
+  ## When 'default' is specified, this is 30x faster than
+  ## base::getOption().  The difference is that here we use
+  ## use names(.Options) whereas in 'base' names(options())
+  ## is used.
+  getOption <- local({
+    go <- base::getOption
+    function(x, default = NULL) {
+      if (missing(default) || match(x, table = names(.Options), nomatch = 0L) > 0L) go(x) else default
+    }
+  })
+}
